package App::dux;

our $VERSION = '1.53'; # VERSION

1;
# ABSTRACT: Run Data::Unixish function on the command-line

__END__

=pod

=encoding UTF-8

=head1 NAME

App::dux - Run Data::Unixish function on the command-line

=head1 VERSION

This document describes version 1.53 of App::dux (from Perl distribution App-dux), released on 2017-07-10.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/App-dux>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-App-dux>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-dux>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2017, 2016, 2015, 2014, 2013, 2012 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
